/*  OpenTally: Open-source election vote counting
 *  Copyright © 2021 Lee Yingtong Li (RunasSudo)
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Affero General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Affero General Public License for more details.
 *
 *  You should have received a copy of the GNU Affero General Public License
 *  along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

mod utils;

use opentally::numbers::Rational;
use opentally::stv;

#[test]
fn ers97_rational() {
	let stv_opts = stv::STVOptionsBuilder::default()
		.round_surplus_fractions(Some(2))
		.round_values(Some(2))
		.round_votes(Some(2))
		.round_quota(Some(2))
		.quota_criterion(stv::QuotaCriterion::GreaterOrEqual)
		.quota_mode(stv::QuotaMode::ERS97)
		.surplus(stv::SurplusMethod::EG)
		.transferable_only(true)
		.exclusion(stv::ExclusionMethod::ByValue)
		.early_bulk_elect(false)
		.bulk_exclude(true)
		.defer_surpluses(true)
		.build().unwrap();
	
	utils::read_validate_election::<Rational>("tests/data/ers97.csv", "tests/data/ers97.blt", stv_opts, None, &["nt", "vre"]);
}
